==> 0.0.1.tar.gz: lib/src/widgets/confirmation.dart <==
import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_payment/ocg_payment.dart';
import 'package:ocg_payment/src/modals/client.dart';

class PaymentConfirmationWidget extends StatelessWidget {
  final PaymentRequest request;
  final Function() onConfirmed;
  const PaymentConfirmationWidget({
    Key key,
    this.request,
    this.onConfirmed,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    PaymentClient client = request?.client;
    int amount = request.amount, taxes = request.taxes;
    String currency = request.currency;
    Color color = (client.color ?? Colors.orange);
    return Container(
      decoration: BoxDecoration(
          color: Colors.white,
          borderRadius: BorderRadius.only(
              topLeft: Radius.circular(12), topRight: Radius.circular(12))),
      padding: EdgeInsets.symmetric(horizontal: 16, vertical: 20),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: [
          Text(
            "Order Summary",
            style: TextStyle(
                color: Colors.black, fontSize: 17, fontWeight: FontWeight.w700),
          ),
          SizedBox(
            height: 20,
          ),
          Container(
            padding: EdgeInsets.all(12),
            decoration: BoxDecoration(
                color: color.withOpacity(0.11),
                borderRadius: BorderRadius.circular(12)),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                ClipRRect(
                  borderRadius: BorderRadius.circular(12),
                  child: Image.network(
                    "${client.icon}",
                    width: 64,
                    height: 64,
                  ),
                ),
                SizedBox(
                  width: 18,
                ),
                Expanded(
                    child: Column(
                  mainAxisSize: MainAxisSize.min,
                  crossAxisAlignment: CrossAxisAlignment.stretch,
                  children: [
                    Text(
                      "${client.title}",
                      style: TextStyle(
                          color: Colors.black,
                          fontSize: 17,
                          fontWeight: FontWeight.w700),
                    ),
                    SizedBox(
                      height: 4,
                    ),
                    Text(
                      "$amount $currency",
                      style: TextStyle(
                          color: Colors.black,
                          fontSize: 15,
                          fontWeight: FontWeight.w600),
                    ),
                    SizedBox(
                      height: 4,
                    ),
                    Text(
                      "${client.category}",
                      style:
                          TextStyle(color: color, fontWeight: FontWeight.w700),
                    ),
                  ],
                )),
              ],
            ),
          ),
          SizedBox(
            height: 18,
          ),
          buildRow("Taxes", "$taxes $currency"),
          Container(
              margin: EdgeInsets.symmetric(vertical: 4), child: Divider()),
          buildRow("Total Amount", "${amount + taxes} $currency"),
          SizedBox(
            height: 28,
          ),
          RoundedButton(
            "Checkout",
            onTap: onConfirmed,
            color: Color(0xff000b4f),
            padding: EdgeInsets.symmetric(
              vertical: 18,
              horizontal: 16,
            ),
            style: TextStyle(
                fontSize: 17, color: Colors.white, fontWeight: FontWeight.bold),
          ),
        ],
      ),
    );
  }

  Widget buildRow(String sb, String tl) {
    return Row(
      children: [
        subtitle(
          sb,
        ),
        Spacer(),
        title(tl)
      ],
    );
  }

  Widget subtitle(String text) {
    return Text(
      "$text",
      style: TextStyle(
          color: Colors.black45, fontSize: 14, fontWeight: FontWeight.w600),
    );
  }

  Widget title(String text) {
    return Text(
      "$text",
      style: TextStyle(
          color: Colors.black, fontSize: 16, fontWeight: FontWeight.w600),
    );
  }
}

==> 0.0.6.tar.gz: lib/src/widgets/confirmation.dart <==
import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_payment/ocg_payment.dart';
import 'package:ocg_payment/src/modals/client.dart';

class PaymentConfirmationWidget extends StatelessWidget {
  final PaymentRequest request;
  final Function() onConfirmed;
  const PaymentConfirmationWidget({
    Key key,
    this.request,
    this.onConfirmed,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    PaymentClient client = request?.client;
    double amount = request.amount, taxes = request.taxes;
    String currency = request.currency;
    Color color = (client.color ?? Colors.orange);
    return Container(
      decoration: BoxDecoration(
          color: Colors.white,
          borderRadius: BorderRadius.only(
              topLeft: Radius.circular(12), topRight: Radius.circular(12))),
      padding: EdgeInsets.symmetric(horizontal: 16, vertical: 20),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: [
          Text(
            "Order Summary",
            style: TextStyle(
                color: Colors.black, fontSize: 17, fontWeight: FontWeight.w700),
          ),
          SizedBox(
            height: 20,
          ),
          Container(
            padding: EdgeInsets.all(12),
            decoration: BoxDecoration(
                color: color.withOpacity(0.11),
                borderRadius: BorderRadius.circular(12)),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                ClipRRect(
                  borderRadius: BorderRadius.circular(12),
                  child: Image.network(
                    "${client.icon}",
                    width: 64,
                    height: 64,
                  ),
                ),
                SizedBox(
                  width: 18,
                ),
                Expanded(
                    child: Column(
                  mainAxisSize: MainAxisSize.min,
                  crossAxisAlignment: CrossAxisAlignment.stretch,
                  children: [
                    Text(
                      "${client.title}",
                      style: TextStyle(
                          color: Colors.black,
                          fontSize: 17,
                          fontWeight: FontWeight.w700),
                    ),
                    SizedBox(
                      height: 4,
                    ),
                    Text(
                      "$amount $currency",
                      style: TextStyle(
                          color: Colors.black,
                          fontSize: 15,
                          fontWeight: FontWeight.w600),
                    ),
                    SizedBox(
                      height: 4,
                    ),
                    Text(
                      "${client.category}",
                      style:
                          TextStyle(color: color, fontWeight: FontWeight.w700),
                    ),
                  ],
                )),
              ],
            ),
          ),
          SizedBox(
            height: 18,
          ),
          buildRow("Taxes", "$taxes $currency"),
          Container(
              margin: EdgeInsets.symmetric(vertical: 4), child: Divider()),
          buildRow("Total Amount", "${amount + taxes} $currency"),
          SizedBox(
            height: 28,
          ),
          RoundedButton(
            "Checkout",
            onTap: onConfirmed,
            color: Color(0xff000b4f),
            padding: EdgeInsets.symmetric(
              vertical: 18,
              horizontal: 16,
            ),
            style: TextStyle(
                fontSize: 17, color: Colors.white, fontWeight: FontWeight.bold),
          ),
        ],
      ),
    );
  }

  Widget buildRow(String sb, String tl) {
    return Row(
      children: [
        subtitle(
          sb,
        ),
        Spacer(),
        title(tl)
      ],
    );
  }

  Widget subtitle(String text) {
    return Text(
      "$text",
      style: TextStyle(
          color: Colors.black45, fontSize: 14, fontWeight: FontWeight.w600),
    );
  }

  Widget title(String text) {
    return Text(
      "$text",
      style: TextStyle(
          color: Colors.black, fontSize: 16, fontWeight: FontWeight.w600),
    );
  }
}
